@@ -1,7 +1,8 @@
-from enum import Enum
+import enum
 
 
-class SyncTypes(Enum):
+@enum.unique
+class SyncTypes(enum.Enum):
     BsSourcedVoice = 0x755FD7DF75F7
     BsSourcedData = 0xDFF57D75DF5D
     MsSourcedVoice = 0x7F7D5DD57DFD
@@ -13,3 +14,7 @@ class SyncTypes(Enum):
     Tdma2Data = 0xD7557F5FF7F5
     Reserved = 0xDD7FF5D757DD
     EmbeddedData = -1
+
+    @classmethod
+    def _missing_(cls, value: object):
+        return SyncTypes.EmbeddedData
