@@ -1,3 +1,6 @@
+from typing import Union
+
+import numpy
 from bitarray import bitarray
 
 
@@ -39,9 +42,13 @@ def byteswap_bytearray(data: bytearray) -> bytes:
     """
     trim = len(data)
     last: bytes = bytes()
-    # add padding, that will get removed, to have odd number of bytes
+    # add padding, that will get removed, to not have odd number of bytes
     if len(data) % 2 != 0:
         last = bytes([data[-1]])
         data = data[0:-1]
     data[0::2], data[1::2] = data[1::2], data[0::2]
     return bytes(data[:trim]) + last
+
+
+def numpy_array_to_int(data: Union[numpy.array, numpy.ndarray]) -> int:
+    return int(data.dot(2 ** numpy.arange(data.size)[::-1]))
