@@ -14,8 +14,8 @@ def test_crc32():
     # fmt:on
     # @formatter:on
 
-    for testtuple in data:
+    for (databytes, expected_crc32) in data:
         assert CRC32.check(
-            data=bytes.fromhex(testtuple[0]),
-            crc32=int.from_bytes(bytes.fromhex(testtuple[1]), byteorder="little"),
-        ), f"CRC32 does not match in ${testtuple}"
+            data=bytes.fromhex(databytes),
+            crc32=int.from_bytes(bytes.fromhex(expected_crc32), byteorder="little"),
+        ), f"CRC32 does not match in {(databytes, expected_crc32)}"
